sequencetools.pair_duration_sequence_elements_with_input_pair_values
====================================================================

.. autofunction:: abjad.tools.sequencetools.pair_duration_sequence_elements_with_input_pair_values.pair_duration_sequence_elements_with_input_pair_values
